@@ -22,7 +22,7 @@
 #include "event.h"
 #include "todo.h"
 
-#include <qtest.h>
+#include <QTest>
 QTEST_MAIN(EventTest)
 
 Q_DECLARE_METATYPE(KCalCore::Incidence::DateTimeRole)
@@ -31,35 +31,37 @@ using namespace KCalCore;
 
 void EventTest::testSetRoles_data()
 {
-    QTest::addColumn<KDateTime>("originalDtStart");
-    QTest::addColumn<KDateTime>("originalDtEnd");
+    QTest::addColumn<QDateTime>("originalDtStart");
+    QTest::addColumn<QDateTime>("originalDtEnd");
+    QTest::addColumn<bool>("allDayEvent");
 
     QTest::addColumn<KCalCore::Incidence::DateTimeRole>("setRole");
-    QTest::addColumn<KDateTime>("dateTimeToSet");
-    QTest::addColumn<KDateTime>("expectedDtStart");
-    QTest::addColumn<KDateTime>("expectedDtEnd");
+    QTest::addColumn<QDateTime>("dateTimeToSet");
+    QTest::addColumn<QDateTime>("expectedDtStart");
+    QTest::addColumn<QDateTime>("expectedDtEnd");
 
-    const KDateTime todayDate(QDate::currentDate());   // all day event
-    const KDateTime todayDateTime = KDateTime::currentUtcDateTime();
+    const QDateTime todayDate(QDate::currentDate(), {});   // all day event
+    const QDateTime todayDateTime = QDateTime::currentDateTimeUtc();
 
-    QTest::newRow("dnd 0 duration") << todayDate << todayDate << KCalCore::Incidence::RoleDnD
+    QTest::newRow("dnd 0 duration") << todayDate << todayDate << true << KCalCore::Incidence::RoleDnD
                                     << todayDateTime << todayDateTime << todayDateTime.addSecs(3600);
 }
 
 void EventTest::testSetRoles()
 {
-    QFETCH(KDateTime, originalDtStart);
-    QFETCH(KDateTime, originalDtEnd);
+    QFETCH(QDateTime, originalDtStart);
+    QFETCH(QDateTime, originalDtEnd);
+    QFETCH(bool, allDayEvent);
     QFETCH(KCalCore::Incidence::DateTimeRole, setRole);
 
-    QFETCH(KDateTime, dateTimeToSet);
-    QFETCH(KDateTime, expectedDtStart);
-    QFETCH(KDateTime, expectedDtEnd);
+    QFETCH(QDateTime, dateTimeToSet);
+    QFETCH(QDateTime, expectedDtStart);
+    QFETCH(QDateTime, expectedDtEnd);
 
     Event::Ptr event = Event::Ptr(new Event());
     event->setDtStart(originalDtStart);
     event->setDtEnd(originalDtEnd);
-    event->setAllDay(originalDtStart.isDateOnly());
+    event->setAllDay(allDayEvent);
 
     event->setDateTime(dateTimeToSet, setRole);
     QCOMPARE(event->dtStart(), expectedDtStart);
@@ -70,81 +72,81 @@ void EventTest::testValidity()
 {
     QDate dt = QDate::currentDate();
     Event *event = new Event();
-    event->setDtStart(KDateTime(dt));
-    event->setDtEnd(KDateTime(dt).addDays(1));
+    event->setDtStart(QDateTime(dt, {}));
+    event->setDtEnd(QDateTime(dt, {}).addDays(1));
     event->setSummary(QStringLiteral("Event1 Summary"));
     event->setDescription(QStringLiteral("This is a description of the first event"));
     event->setLocation(QStringLiteral("the place"));
-    //KDE5: QVERIFY( event->typeStr() == i18n( "event" ) );
-    QVERIFY(event->summary() == QLatin1String("Event1 Summary"));
-    QVERIFY(event->location() == QLatin1String("the place"));
-    QVERIFY(event->type() == Incidence::TypeEvent);
+
+    QCOMPARE(event->summary(), QStringLiteral("Event1 Summary"));
+    QCOMPARE(event->location(), QStringLiteral("the place"));
+    QCOMPARE(event->type(), Incidence::TypeEvent);
 }
 
 void EventTest::testCompare()
 {
     QDate dt = QDate::currentDate();
     Event event1;
-    event1.setDtStart(KDateTime(dt));
-    event1.setDtEnd(KDateTime(dt).addDays(1));
+    event1.setDtStart(QDateTime(dt, {}));
+    event1.setDtEnd(QDateTime(dt, {}).addDays(1));
     event1.setSummary(QStringLiteral("Event1 Summary"));
     event1.setDescription(QStringLiteral("This is a description of the first event"));
     event1.setLocation(QStringLiteral("the place"));
 
     Event event2;
-    event2.setDtStart(KDateTime(dt).addDays(1));
-    event2.setDtEnd(KDateTime(dt).addDays(2));
+    event2.setDtStart(QDateTime(dt, {}).addDays(1));
+    event2.setDtEnd(QDateTime(dt, {}).addDays(2));
     event2.setSummary(QStringLiteral("Event2 Summary"));
     event2.setDescription(QStringLiteral("This is a description of the second event"));
     event2.setLocation(QStringLiteral("the other place"));
 
     QVERIFY(!(event1 == event2));
-    QVERIFY(event1.dtEnd() == event2.dtStart());
-    QVERIFY(event2.summary() == QLatin1String("Event2 Summary"));
+    QCOMPARE(event1.dtEnd(), event2.dtStart());
+    QCOMPARE(event2.summary(), QStringLiteral("Event2 Summary"));
 }
 
 void EventTest::testClone()
 {
     QDate dt = QDate::currentDate();
     Event event1;
-    event1.setDtStart(KDateTime(dt));
-    event1.setDtEnd(KDateTime(dt).addDays(1));
+    event1.setDtStart(QDateTime(dt, {}));
+    event1.setDtEnd(QDateTime(dt, {}).addDays(1));
     event1.setSummary(QStringLiteral("Event1 Summary"));
     event1.setDescription(QStringLiteral("This is a description of the first event"));
     event1.setLocation(QStringLiteral("the place"));
 
     Event *event2 = event1.clone();
-    QVERIFY(event1.summary() == event2->summary());
-    QVERIFY(event1.dtStart() == event2->dtStart());
-    QVERIFY(event1.dtEnd() == event2->dtEnd());
-    QVERIFY(event1.description() == event2->description());
-    QVERIFY(event1.location() == event2->location());
+    QCOMPARE(event1.summary(), event2->summary());
+    QCOMPARE(event1.dtStart(), event2->dtStart());
+    QCOMPARE(event1.dtEnd(), event2->dtEnd());
+    QCOMPARE(event1.description(), event2->description());
+    QCOMPARE(event1.location(), event2->location());
 }
 
 void EventTest::testCopy()
 {
     QDate dt = QDate::currentDate();
     Event event1;
-    event1.setDtStart(KDateTime(dt));
-    event1.setDtEnd(KDateTime(dt).addDays(1));
+    event1.setDtStart(QDateTime(dt, {}));
+    event1.setDtEnd(QDateTime(dt, {}).addDays(1));
     event1.setSummary(QStringLiteral("Event1 Summary"));
     event1.setDescription(QStringLiteral("This is a description of the first event"));
     event1.setLocation(QStringLiteral("the place"));
     event1.setTransparency(Event::Transparent);
 
     Event event2 = event1;
-    QVERIFY(event1.summary() == event2.summary());
-    QVERIFY(event1.dtStart() == event2.dtStart());
-    QVERIFY(event1.dtEnd() == event2.dtEnd());
-    QVERIFY(event1.description() == event2.description());
-    QVERIFY(event1.location() == event2.location());
+    QCOMPARE(event1.summary(), event2.summary());
+    QCOMPARE(event1.dtStart(), event2.dtStart());
+    QCOMPARE(event1.dtEnd(), event2.dtEnd());
+    QCOMPARE(event1.description(), event2.description());
+    QCOMPARE(event1.location(), event2.location());
 }
 
 void EventTest::testCopyIncidence()
 {
     QDate dt = QDate::currentDate();
     Todo todo;
-    todo.setDtStart(KDateTime(dt));
+    todo.setDtStart(QDateTime(dt, {}));
     todo.setSummary(QStringLiteral("Event1 Summary"));
     todo.setDescription(QStringLiteral("This is a description of the first event"));
     todo.setLocation(QStringLiteral("the place"));
@@ -161,22 +163,22 @@ void EventTest::testAssign()
 {
     QDate dt = QDate::currentDate();
     Event event1;
-    event1.setDtStart(KDateTime(dt));
-    event1.setDtEnd(KDateTime(dt).addDays(1));
+    event1.setDtStart(QDateTime(dt, {}));
+    event1.setDtEnd(QDateTime(dt, {}).addDays(1));
     event1.setSummary(QStringLiteral("Event1 Summary"));
     event1.setDescription(QStringLiteral("This is a description of the first event"));
     event1.setLocation(QStringLiteral("the place"));
     event1.setTransparency(Event::Transparent);
 
     Event event2 = event1;
-    QVERIFY(event1 == event2);
+    QCOMPARE(event1, event2);
 }
 
 void EventTest::testSerializer_data()
 {
     QTest::addColumn<KCalCore::Event::Ptr>("event");
-    KDateTime today = KDateTime::currentUtcDateTime();
-    KDateTime yesterday = today.addDays(-1);
+    QDateTime today = QDateTime::currentDateTimeUtc();
+    QDateTime yesterday = today.addDays(-1);
 
     Event::Ptr event1 = Event::Ptr(new Event());
     Attendee::Ptr attendee1(new Attendee(QStringLiteral("fred"), QStringLiteral("fred@flintstone.com")));
@@ -216,7 +218,7 @@ void EventTest::testSerializer()
     QVERIFY(*event != *event2);
     QDataStream stream2(&array, QIODevice::ReadOnly);
     stream2 >> incidenceBase2;
-    QVERIFY(*event == *event2);
+    QCOMPARE(*event, *event2);
 }
 
 void EventTest::testDurationDtEnd()
@@ -225,69 +227,75 @@ void EventTest::testDurationDtEnd()
 
     {
         Event event;
-        event.setDtStart(KDateTime(dt));
-        event.setDtEnd(KDateTime(dt).addDays(1));
+        event.setDtStart(QDateTime(dt, {}));
+        event.setDtEnd(QDateTime(dt, {}).addDays(1));
         QCOMPARE(event.hasEndDate(), true);
         QCOMPARE(event.hasDuration(), false);
     }
     {
         Event event;
-        event.setDtStart(KDateTime(dt));
-        event.setDuration(Duration(KDateTime(dt), KDateTime(dt).addDays(1)));
+        event.setDtStart(QDateTime(dt, {}));
+        event.setDuration(Duration(QDateTime(dt, {}), QDateTime(dt, {}).addDays(1)));
         QCOMPARE(event.hasDuration(), true);
         QCOMPARE(event.hasEndDate(), false);
     }
-
 }
 
 void EventTest::testDtEndChange()
 {
     QDate dt = QDate::currentDate();
     Event event1;
-    event1.setDtStart(KDateTime(dt));
-    event1.setDtEnd(KDateTime(dt).addDays(1));
+    event1.setDtStart(QDateTime(dt, {}));
+    event1.setDtEnd(QDateTime(dt, {}).addDays(1));
     event1.resetDirtyFields();
 
-    event1.setDtEnd(KDateTime(dt).addDays(1));
+    event1.setDtEnd(QDateTime(dt, {}).addDays(1));
     QVERIFY(event1.dirtyFields().empty());
 
-    event1.setDtEnd(KDateTime(dt).addDays(2));
+    event1.setDtEnd(QDateTime(dt, {}).addDays(2));
     QCOMPARE(event1.dirtyFields(), QSet<IncidenceBase::Field>() << IncidenceBase::FieldDtEnd);
     event1.resetDirtyFields();
 
-    event1.setDtEnd(KDateTime());
+    event1.setDtEnd(QDateTime());
     QCOMPARE(event1.dirtyFields(), QSet<IncidenceBase::Field>() << IncidenceBase::FieldDtEnd);
     event1.resetDirtyFields();
 
-    event1.setDtEnd(KDateTime(dt).addDays(2));
+    event1.setDtEnd(QDateTime(dt, {}).addDays(2));
     QCOMPARE(event1.dirtyFields(), QSet<IncidenceBase::Field>() << IncidenceBase::FieldDtEnd);
 }
 
 void EventTest::testIsMultiDay_data()
 {
-    QTest::addColumn<KDateTime>("start");
-    QTest::addColumn<KDateTime>("end");
+    QTest::addColumn<QDateTime>("start");
+    QTest::addColumn<QDateTime>("end");
     QTest::addColumn<bool>("isMultiDay");
 
-    QTest::newRow("event0") << KDateTime(QDate(2016, 7, 9), QTime(12, 0, 0)) << KDateTime(QDate(2016, 7, 9), QTime(13, 0, 0)) << false;
+    QTest::newRow("event0") << QDateTime(QDate(2016, 7, 9), QTime(12, 0, 0))
+                            << QDateTime(QDate(2016, 7, 9), QTime(13, 0, 0)) << false;
 
-    QTest::newRow("event1") << KDateTime(QDate(2016, 7, 9), QTime(12, 0, 0)) << KDateTime(QDate(2016, 7, 10), QTime(0, 0, 0)) << false;
+    QTest::newRow("event1") << QDateTime(QDate(2016, 7, 9), QTime(12, 0, 0))
+                            << QDateTime(QDate(2016, 7, 10), QTime(0, 0, 0)) << false;
 
-    QTest::newRow("event2") << KDateTime(QDate(2016, 7, 9), QTime(12, 0, 0)) << KDateTime(QDate(2016, 7, 10), QTime(12, 0, 0)) << true;
+    QTest::newRow("event2") << QDateTime(QDate(2016, 7, 9), QTime(12, 0, 0))
+                            << QDateTime(QDate(2016, 7, 10), QTime(12, 0, 0)) << true;
 
-    QTest::newRow("event3") << KDateTime(QDate(2016, 12, 31), QTime(0, 0, 0)) << KDateTime(QDate(2017, 1, 1), QTime(0, 0, 0)) << false;
+    QTest::newRow("event3") << QDateTime(QDate(2016, 12, 31), QTime(0, 0, 0))
+                            << QDateTime(QDate(2017, 1, 1), QTime(0, 0, 0)) << false;
 
-    QTest::newRow("event4") << KDateTime(QDate(2016, 12, 31), QTime(0, 0, 1)) << KDateTime(QDate(2017, 1, 1), QTime(0, 0, 1)) << true;
+    QTest::newRow("event4") << QDateTime(QDate(2016, 12, 31), QTime(0, 0, 1))
+                            << QDateTime(QDate(2017, 1, 1), QTime(0, 0, 1)) << true;
 
-    QTest::newRow("event5") << KDateTime(QDate(2016, 12, 31), QTime(12, 0, 0)) << KDateTime(QDate(2017, 1, 1), QTime(12, 0, 0)) << true;
+    QTest::newRow("event5") << QDateTime(QDate(2016, 12, 31), QTime(12, 0, 0))
+                            << QDateTime(QDate(2017, 1, 1), QTime(12, 0, 0)) << true;
 
-    QTest::newRow("event6") << KDateTime(QDate(2016, 12, 24), QTime(12, 0, 0)) << KDateTime(QDate(2017, 1, 1), QTime(0, 0, 0)) << true;
+    QTest::newRow("event6") << QDateTime(QDate(2016, 12, 24), QTime(12, 0, 0))
+                            << QDateTime(QDate(2017, 1, 1), QTime(0, 0, 0)) << true;
 }
 
 void EventTest::testIsMultiDay()
 {
-    QFETCH(KDateTime, start);
-    QFETCH(KDateTime, end);
+    QFETCH(QDateTime, start);
+    QFETCH(QDateTime, end);
     QFETCH(bool, isMultiDay);
 
     Event event;
